@@ -60,43 +60,41 @@ class Wrapper:
         return info["external_linkage_info"]["annofab"].get("account_id")
 
     @allow_404_error(logger=logger)
-    def get_organization_or_none(self, organization_id: str) -> Optional[dict[str, Any]]:
-        return self.api.get_organization(organization_id, log_response_with_error=False)
+    def get_workspace_or_none(self, workspace_id: str) -> Optional[dict[str, Any]]:
+        return self.api.get_workspace(workspace_id, log_response_with_error=False)
 
     @allow_404_error(logger=logger)
-    def get_organization_tag_or_none(self, organization_id: str, organization_tag_id: str) -> Optional[dict[str, Any]]:
-        return self.api.get_organization_tag(organization_id, organization_tag_id, log_response_with_error=False)
+    def get_workspace_tag_or_none(self, workspace_id: str, workspace_tag_id: str) -> Optional[dict[str, Any]]:
+        return self.api.get_workspace_tag(workspace_id, workspace_tag_id, log_response_with_error=False)
 
     @allow_404_error(logger=logger)
-    def get_job_or_none(self, organization_id: str, job_id: str) -> Optional[dict[str, Any]]:
-        return self.api.get_job(organization_id, job_id, log_response_with_error=False)
+    def get_job_or_none(self, workspace_id: str, job_id: str) -> Optional[dict[str, Any]]:
+        return self.api.get_job(workspace_id, job_id, log_response_with_error=False)
 
     @allow_404_error(logger=logger)
-    def get_job_children_or_none(self, organization_id: str, job_id: str) -> Optional[list[dict[str, Any]]]:
-        return self.api.get_job_children(organization_id, job_id, log_response_with_error=False)
+    def get_job_children_or_none(self, workspace_id: str, job_id: str) -> Optional[list[dict[str, Any]]]:
+        return self.api.get_job_children(workspace_id, job_id, log_response_with_error=False)
 
     @allow_404_error(logger=logger)
-    def get_organization_member_or_none(
-        self, organization_id: str, organization_member_id: str
-    ) -> Optional[dict[str, Any]]:
-        return self.api.get_organization_member(organization_id, organization_member_id, log_response_with_error=False)
+    def get_workspace_member_or_none(self, workspace_id: str, workspace_member_id: str) -> Optional[dict[str, Any]]:
+        return self.api.get_workspace_member(workspace_id, workspace_member_id, log_response_with_error=False)
 
     ###################################################################################################################
     # actual_working_time
     ###################################################################################################################
     def get_actual_working_times_daily(
         self,
-        organization_id: str,
+        workspace_id: str,
         *,
         job_id: Optional[str] = None,
         term_start_date: Optional[str] = None,
         term_end_date: Optional[str] = None,
         tzinfo: Optional[datetime.tzinfo] = None,
     ) -> list[dict[str, Any]]:
-        """組織全体の実績時間を一括取得します。実績時間は日、ジョブ、メンバ単位で集計されています。
+        """ワークスペース全体の実績時間を一括取得します。実績時間は日、ジョブ、メンバ単位で集計されています。
 
         Args:
-            organization_id (str):  組織ID (required)
+            workspace_id (str):  ワークスペースID (required)
             job_id (str):  ジョブIDで絞り込みます。
             term_start_date (str): 検索範囲の開始日（YYYY-MM-DD）
             term_end_date (str):  検索範囲の終了日（YYYY-MM-DD）
@@ -106,7 +104,7 @@ class Wrapper:
             日付、ジョブ、メンバ単位で集計した実績時間のlistを返します。listの要素はdictで以下のキーを持ちます。
             * date
             * job_id
-            * organization_member_id
+            * workspace_member_id
             * actual_working_hours
 
         """
@@ -118,27 +116,27 @@ class Wrapper:
             "term_start": term_start,
             "term_end": term_end,
         }
-        tmp = self.api.get_actual_working_times(organization_id, query_params=query_params)
+        tmp = self.api.get_actual_working_times(workspace_id, query_params=query_params)
         daily_list = create_actual_working_times_daily(tmp, tzinfo=tzinfo)
         return _filter_actual_working_times_daily(
             daily_list, term_start_date=term_start_date, term_end_date=term_end_date
         )
 
-    def get_actual_working_times_by_organization_member_daily(
+    def get_actual_working_times_by_workspace_member_daily(
         self,
-        organization_id: str,
-        organization_member_id: str,
+        workspace_id: str,
+        workspace_member_id: str,
         *,
         term_start_date: Optional[str] = None,
         term_end_date: Optional[str] = None,
         tzinfo: Optional[datetime.tzinfo] = None,
     ) -> Any:
-        """組織メンバーに対する実績時間を一括取得します。実績時間は日、ジョブ、メンバ単位で集計されています。
+        """ワークスペースメンバーに対する実績時間を一括取得します。実績時間は日、ジョブ、メンバ単位で集計されています。
 
 
         Args:
-            organization_id (str):  組織ID (required)
-            organization_member_id (str):  組織メンバーID (required)
+            workspace_id (str):  ワークスペースID (required)
+            workspace_member_id (str):  ワークスペースメンバーID (required)
             term_start_date (str): 検索範囲の開始日（YYYY-MM-DD）
             term_end_date (str):  検索範囲の終了日（YYYY-MM-DD）
             tzinfo: 日付を決めるためのタイムゾーン。未指定の場合はシステムのタイムゾーンを参照します。
@@ -147,7 +145,7 @@ class Wrapper:
             日付、ジョブ、メンバ単位で集計した実績時間のlistを返します。listの要素はdictで以下のキーを持ちます。
             * date
             * job_id
-            * organization_member_id
+            * workspace_member_id
             * actual_working_hours
 
         """
@@ -158,8 +156,8 @@ class Wrapper:
             "term_start": term_start,
             "term_end": term_end,
         }
-        tmp = self.api.get_actual_working_times_by_organization_member(
-            organization_id, organization_member_id, query_params=query_params
+        tmp = self.api.get_actual_working_times_by_workspace_member(
+            workspace_id, workspace_member_id, query_params=query_params
         )
         daily_list = create_actual_working_times_daily(tmp, tzinfo=tzinfo)
         return _filter_actual_working_times_daily(
@@ -172,7 +170,7 @@ class Wrapper:
 
     def get_schedules_daily(
         self,
-        organization_id: str,
+        workspace_id: str,
         *,
         term_start: Optional[str] = None,
         term_end: Optional[str] = None,
@@ -184,7 +182,7 @@ class Wrapper:
             内部で `api.get_expected_working_times` を実行します。
 
         Args:
-            organization_id: 組織ID
+            workspace_id: ワークスペースID
             term_start_date (str): 検索範囲の開始日（YYYY-MM-DD）
             term_end_date (str):  検索範囲の終了日（YYYY-MM-DD）
             job_id (str): 検索対象のジョブID
@@ -193,7 +191,7 @@ class Wrapper:
             日、ジョブ、メンバ単位のアサイン時間のlist。listの要素は以下のキーを持ちます。
             * date
             * job_id
-            * organization_member_id
+            * workspace_member_id
             * assigned_working_hours
         """
 
@@ -206,7 +204,7 @@ class Wrapper:
             return min_date, max_date
 
         schedule_list = self.api.get_schedules(
-            organization_id, query_params={"job_id": job_id, "term_start": term_start, "term_end": term_end}
+            workspace_id, query_params={"job_id": job_id, "term_start": term_start, "term_end": term_end}
         )
 
         if len(schedule_list) == 0:
@@ -214,10 +212,10 @@ class Wrapper:
 
         min_date, max_date = _get_min_max_date(schedule_list)
         expected_working_times = self.api.get_expected_working_times(
-            organization_id, query_params={"term_start": min_date, "term_end": max_date}
+            workspace_id, query_params={"term_start": min_date, "term_end": max_date}
         )
         expected_working_hours_dict: _ExpectedWorkingHoursDict = {
-            (e["date"], e["organization_member_id"]): e["expected_working_hours"]
+            (e["date"], e["workspace_member_id"]): e["expected_working_hours"]
             for e in expected_working_times
             if e["expected_working_hours"] > 0
         }
@@ -227,12 +225,10 @@ class Wrapper:
         for schedule in schedule_list:
             schedules_daily = create_schedules_daily(schedule, expected_working_hours_dict)
             for elm in schedules_daily:
-                result_dict[(elm["date"], elm["organization_member_id"], elm["job_id"])] += elm[
-                    "assigned_working_hours"
-                ]
+                result_dict[(elm["date"], elm["workspace_member_id"], elm["job_id"])] += elm["assigned_working_hours"]
 
         result_list = []
-        for (date, tmp_organization_member_id, tmp_job_id), assigned_working_hours in result_dict.items():
+        for (date, tmp_workspace_member_id, tmp_job_id), assigned_working_hours in result_dict.items():
             if assigned_working_hours == 0:
                 # アサイン時間が0の情報は不要なので、出力しないようにする
                 continue
@@ -245,7 +241,7 @@ class Wrapper:
             result_list.append(
                 dict(
                     date=date,
-                    organization_member_id=tmp_organization_member_id,
+                    workspace_member_id=tmp_workspace_member_id,
                     job_id=tmp_job_id,
                     assigned_working_hours=assigned_working_hours,
                 )
